/****************************************************************************
**
** qutIM instant messenger
**
** Copyright (C) 2011 Ruslan Nigmatullin <euroelessar@ya.ru>
**
*****************************************************************************
**
** $QUTIM_BEGIN_LICENSE$
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see http://www.gnu.org/licenses/.
** $QUTIM_END_LICENSE$
**
****************************************************************************/

import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0
import org.qutim 0.3
import "components"

Page {
	id: root
	property variant contactList
	property variant showOffline:false
	property variant chat
	PageHeader {
		id: header
		anchors.top: parent.top
		text: contactList.statusName(contactList.status)
		clickable: true
		property Sheet accountList
		iconSource: contactList.statusUrl(contactList.status)
		onClicked: {
			accountList = accountListComponent.createObject(root)
			accountList.open()
		}
	}

	ContactListModel {
		id: listModel
		showOffline: root.showOffline
		statusPrefix: "icon-m"
	}
	ControlledMenu {
		id: contactMenu
		visualParent: pageStack
	}
	ListView {
		id: listViewItem
		anchors{top: header.bottom; bottom: parent.bottom; left:parent.left; right:parent.right}
		model: listModel
		header: SearchBar {
			id: searchBar
			placeholderText: qsTr("Search contact")
			onSearchingTextChanged: {
				listModel.filter = searchingText;
			}
		}
		delegate: ContactItem {
			onClicked: {
				var session = root.chat.session(model.contact);
				chat.activeSession = session;
				root.chat.show();
			}
			onPressAndHold: {
				contactMenu.controller = model.contact;
				contactMenu.open();
			}
		}

		section.property: "alphabet"
		section.criteria: ViewSection.FullString
		section.delegate: sectionHeading
		clip:true
	}
	// The delegate for each section header
	Component {
		id: sectionHeading
		Rectangle {
			width: root.width
			height: childrenRect.height
			color: Qt.rgba(0, 0, 0, 0.2)
			Text {
				anchors.right: parent.right
				anchors.rightMargin: 15
				text: section
				font.bold: true
				font.pixelSize: 20
			}
		}
	}

	SectionScroller {
		listView: listViewItem
	}
	ScrollDecorator {
		flickableItem: listViewItem
	}
	Component {
		id: accountListComponent
		Sheet {
			id: accountListContent
			rejectButtonText: qsTr("Cancel")
			onRejected: accountListContent.destroy()
			content: Flickable {
				anchors.fill: parent
				anchors.leftMargin: 10
				anchors.topMargin: 10
				contentWidth: accountListColumn.width
				contentHeight: accountListColumn.height
				flickableDirection: Flickable.VerticalFlick

				Column {
					id: accountListColumn
					anchors.top: parent.top
					spacing: 10
					Repeater {
						model: [
							Status.Online,
							Status.FreeChat,
							Status.Away,
							Status.DND,
							Status.NA,
							Status.Invisible,
							Status.Offline
						]
						Button {
							text: contactList.statusName(modelData)
							iconSource: contactList.statusUrl(modelData)
							onClicked: {
								contactList.status = modelData
								accountListContent.destroy()
							}
						}
					}
					Repeater {
						model: contactList.accounts
						Button {
							text: modelData.id
							iconSource: contactList.statusUrl(modelData.status)
							onClicked: {
								accountMenu.controller = modelData
								accountMenu.open()
							}
						}
					}
				}
			}
			ControlledMenu {
				id: accountMenu
				visualParent: accountListContent
				onStatusChanged: {
					if (status == DialogStatus.Closing)
						accountListContent.reject()
				}
			}
		}
	}
}
